package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Mar 22, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
Success = "SUCCESS"
Error = "ERROR"
)
type ErrorLog struct {
Scope string `json:"scope,omitempty"`
StatusCode string `json:"status,omitempty"`
Trace string `json:"trace,omitempty"`
RootCause string `json:"rootCause,omitempty"`
Query string `json:"query,omitempty"`
ExceptionType string `json:"exceptionType,omitempty"`
}
type Message struct {
ErrorLog ErrorLogs `json:"errorLog,omitempty"`
HostName string `json:"hostName,omitempty"`
Status string `json:"status,omitempty"`
TimeTaken string `json:"timeTaken,omitempty"`
Count int `json:"count,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.